﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;
using HeuristicLab.Common;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Hive.Contracts.ResponseObjects {
  [StorableClass]
  [DataContract]
  [Serializable]
  public class ResponseList<T> : Response where T : class, IDeepCloneable {
    [Storable]
    [DataMember]
    public IList<T> List { get; set; }

    public ResponseList() {
      this.List = new List<T>();
    }
    [StorableConstructor]
    protected ResponseList(bool deserializing) : base(deserializing) { }
    protected ResponseList(ResponseList<T> original, Cloner cloner)
      : base(original, cloner) {
      this.List = (original.List.Select(x => cloner.Clone(x))).ToList();
    }
    public override IDeepCloneable Clone(Cloner cloner) {
      return new ResponseList<T>(this, cloner);
    }
  }
}
